'use strict';

exports.__esModule = true;

var _assign = require('babel-runtime/core-js/object/assign');

var _assign2 = _interopRequireDefault(_assign);

exports.xScaleLinear = xScaleLinear;
exports.xScaleTime = xScaleTime;
exports.xScaleBand = xScaleBand;
exports.yScaleLinear = yScaleLinear;
exports.xScaleLinearDataList = xScaleLinearDataList;
exports.yScaleLinearDataList = yScaleLinearDataList;
exports.xScaleTimeList = xScaleTimeList;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var d3 = (0, _assign2['default'])({}, require('d3-shape'), require('d3-format'), require('d3-axis'), require('d3-array'), require('d3-scale'), require('d3-time-format'));
function getMax(data, axisType) {
  return d3.max(data, function (d) {
    return d[axisType];
  });
}

function getMin(data, axisType) {
  return d3.min(data, function (d) {
    return d[axisType];
  });
}

function xScaleLinear(data, width) {
  return d3.scaleLinear().domain([0, getMax(data, 'x')]).range([0, width]);
}

function xScaleTime(data, width) {
  return d3.scaleTime().domain(d3.extent(data, function (d) {
    return d.x;
  })).rangeRound([0, width]);
}

function xScaleBand(data, width, paddingPercent) {
  return d3.scaleBand().domain(data.map(function (d) {
    return d.x;
  })).rangeRound([0, width]).padding(paddingPercent);
}

function yScaleLinear(data, height, yBuffer) {
  return d3.scaleLinear().domain([0, getMax(data, 'y') + yBuffer]).range([height, 0]);
}

function getMaxFromList(dataList, axisType) {
  return d3.max(dataList.map(function (data) {
    return getMax(data, axisType);
  }));
}

function getMinFromList(dataList, axisType) {
  return d3.min(dataList.map(function (data) {
    return getMin(data, axisType);
  }));
}
function xScaleLinearDataList(dataList, width) {
  return d3.scaleLinear().domain([0, getMaxFromList(dataList, 'x')]).range([0, width]);
}

function yScaleLinearDataList(dataList, width) {
  return d3.scaleLinear().domain([getMinFromList(dataList, 'y'), getMaxFromList(dataList, 'y')]).range([0, width]);
}
function xScaleTimeList(dataList, width) {
  return d3.scaleTime().domain(getMinFromList(dataList, 'x'), getMaxFromList(dataList, 'y')).rangeRound([0, width]);
}
//# sourceMappingURL=utils.js.map